@@ -60,20 +60,19 @@
 //!   3. `$HOME/.config/alacritty/alacritty.yml`
 //!   4. `$HOME/.alacritty.yml`
 
-use std::error::Error;
 use std::fs;
-use std::env;
 use std::path::PathBuf;
 
-use crate::themeable::{ConfigError, ConfigState, Themeable};
-use crate::operation::Operation;
 use crate::config::Config as ThconConfig;
-use crate::Disableable;
+use crate::operation::Operation;
+use crate::themeable::{ConfigError, ConfigState, Themeable};
 use crate::AppConfig;
+use crate::Disableable;
 
-use log::{error, debug};
+use anyhow::{Context, Result};
+use log::{debug, error};
+use regex::{Captures, Regex};
 use serde::Deserialize;
-use regex::{Captures,Regex};
 
 #[derive(Debug, Deserialize, Disableable, AppConfig)]
 pub struct _Config {
@@ -92,9 +91,11 @@ impl Themeable for Alacritty {
         ConfigState::with_manual_config(config.alacritty.as_ref().map(|c| c.inner.as_ref()))
     }
 
-    fn switch(&self, config: &ThconConfig, operation: &Operation) -> Result<(), Box<dyn Error>> {
+    fn switch(&self, config: &ThconConfig, operation: &Operation) -> Result<()> {
         let config = match self.config_state(config) {
-            ConfigState::NoDefault => return Err(Box::from(ConfigError::RequiresManualConfig("alacritty"))),
+            ConfigState::NoDefault => {
+                return Err(ConfigError::RequiresManualConfig("alacritty").into())
+            }
             ConfigState::Default => unreachable!(),
             ConfigState::Disabled => return Ok(()),
             ConfigState::Enabled => config.alacritty.as_ref().unwrap().unwrap_inner_left(),
@@ -119,25 +120,37 @@ impl Themeable for Alacritty {
             }
         };
 
-        debug!("Reading/writing alacritty.yml at {}", alacritty_yaml.display());
+        debug!(
+            "Reading/writing alacritty.yml at {}",
+            alacritty_yaml.display()
+        );
 
-        match fs::read_to_string(&alacritty_yaml) {
+        match fs::read_to_string(&alacritty_yaml)
+            .with_context(|| format!("Unable to read settings from {}", &alacritty_yaml.display()))
+        {
             Ok(settings) => {
-                let theme_regex = Regex::new(r#"^(?P<prefix>"?colors"?\s*:\s*"?)(?P<v>[^\s]+)(?P<suffix>"?,?\s*#\s*thcon:replace-line)"#)?;
-                let modified_lines: Vec<String> = settings.lines().map(|line| {
-                    theme_regex.replace(line, |caps: &Captures| {
-                        format!("{}*{}{}", &caps["prefix"], theme, &caps["suffix"])
-                    }).into_owned()
-                }).collect();
+                let theme_regex = Regex::new(
+                    r#"^(?P<prefix>"?colors"?\s*:\s*"?)(?P<v>[^\s]+)(?P<suffix>"?,?\s*#\s*thcon:replace-line)"#,
+                )?;
+                let modified_lines: Vec<String> = settings
+                    .lines()
+                    .map(|line| {
+                        theme_regex
+                            .replace(line, |caps: &Captures| {
+                                format!("{}*{}{}", &caps["prefix"], theme, &caps["suffix"])
+                            })
+                            .into_owned()
+                    })
+                    .collect();
                 let settings = modified_lines.join("\n");
 
-                fs::write(&alacritty_yaml, settings).map_err(|err| {
-                    Box::new(err) as Box<dyn Error>
+                fs::write(&alacritty_yaml, settings).with_context(|| {
+                    format!("Unable to write settings to {}", &alacritty_yaml.display())
                 })
-            },
+            }
             Err(e) => {
                 error!("Unable to read settings: {}", e);
-                Err(Box::new(e))
+                Err(e)
             }
         }
     }
@@ -154,6 +167,8 @@ impl Themeable for Alacritty {
 /// 4. $HOME/.alacritty.yml
 #[cfg(not(windows))]
 fn alacritty_config() -> Option<PathBuf> {
+    use std::env;
+
     // Try using XDG location by default.
     xdg::BaseDirectories::with_prefix("alacritty")
         .ok()
@@ -184,5 +199,7 @@ fn alacritty_config() -> Option<PathBuf> {
 // https://github.com/alacritty/alacritty/blob/5a3bf69e3fd771271921f62219cdb8f920db39ee/alacritty/src/config/mod.rs#L236-L274
 #[cfg(windows)]
 fn alacritty_config() -> Option<PathBuf> {
-    dirs::config_dir().map(|path| path.join("alacritty\\alacritty.yml")).filter(|new| new.exists())
+    dirs::config_dir()
+        .map(|path| path.join("alacritty\\alacritty.yml"))
+        .filter(|new| new.exists())
 }
