@@ -12,7 +12,10 @@ pub mod dirs;
 pub mod sockets;
 pub use config::Config;
 pub use operation::Operation;
-pub use themeable::{Themeable, ConfigState};
-pub use thcon_trait::Disableable;
+pub use thcon_macro::AppConfig;
 pub use thcon_macro::Disableable;
-pub use thcon_macro::AppConfig;
\ No newline at end of file
+pub use thcon_trait::Disableable;
+pub use themeable::{ConfigState, Themeable};
+
+mod switch;
+pub use switch::switch;
